@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '1.02'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '1.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -80,6 +80,7 @@ has cleanser => (
 # role: requires 'hook_before_run'
 # role: optional 'hook_before_read_config_file'
 # role: requires 'hook_after_parse_argv'
+# role: optional 'hook_after_read_config_file'
 # role: requires 'hook_format_result'
 # role: requires 'hook_format_row'
 # role: requires 'hook_display_result'
@@ -325,6 +326,8 @@ sub __default_env_name {
 
 sub hook_before_read_config_file {}
 
+sub hook_after_read_config_file {}
+
 sub get_meta {
     my ($self, $r, $url) = @_;
 
@@ -419,7 +422,7 @@ sub _read_env {
     my $words;
     if ($r->{shell} eq 'bash') {
         require Complete::Bash;
-        ($words, undef) = @{ Complete::Bash::parse_cmdline($env, 0,'') };
+        ($words, undef) = @{ Complete::Bash::parse_cmdline($env, 0) };
     } elsif ($r->{shell} eq 'fish') {
         require Complete::Fish;
         ($words, undef) = @{ Complete::Fish::parse_cmdline($env) };
@@ -444,16 +447,16 @@ sub do_completion {
     my ($words, $cword);
     if ($r->{shell} eq 'bash') {
         require Complete::Bash;
-        ($words, $cword) = @{ Complete::Bash::parse_cmdline(undef,undef,'=') };
+        ($words, $cword) = @{ Complete::Bash::parse_cmdline() };
     } elsif ($r->{shell} eq 'fish') {
         require Complete::Fish;
-        ($words, $cword) = @{ Complete::Fish::parse_cmdline(undef) }; # XXX also break on '='
+        ($words, $cword) = @{ Complete::Fish::parse_cmdline() };
     } elsif ($r->{shell} eq 'tcsh') {
         require Complete::Tcsh;
-        ($words, $cword) = @{ Complete::Tcsh::parse_cmdline(undef) }; # XXX also break on '='
+        ($words, $cword) = @{ Complete::Tcsh::parse_cmdline() };
     } elsif ($r->{shell} eq 'zsh') {
         require Complete::Zsh;
-        ($words, $cword) = @{ Complete::Zsh::parse_cmdline(undef) }; # XXX also break on '='
+        ($words, $cword) = @{ Complete::Zsh::parse_cmdline() };
     } else {
         die "Unsupported shell '$r->{shell}'";
     }
@@ -674,10 +677,15 @@ sub _parse_argv2 {
 
         # then read from configuration
         if ($r->{read_config}) {
+
             $log->tracef("[pericmd] Running hook_before_read_config_file ...");
             $self->hook_before_read_config_file($r);
 
             $self->_read_config($r);
+
+            $log->tracef("[pericmd] Running hook_after_read_config_file ...");
+            $self->hook_after_read_config_file($r);
+
             my $res = Perinci::CmdLine::Util::Config::get_args_from_config(
                 config             => $r->{config},
                 args               => \%args,
@@ -697,6 +705,7 @@ sub _parse_argv2 {
                 return [412, "Profile '$r->{config_profile}' not found ".
                             "in configuration file"];
             }
+
         }
 
         # finally get from argv
@@ -1205,7 +1214,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.02 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-30.
+This document describes version 1.03 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-01.
 
 =head1 DESCRIPTION
 
@@ -1868,6 +1877,14 @@ below is by order of calling.
 Called at the start of C<run()>. Can be used to set some initial values of other
 C<$r> keys. Or setup the logger.
 
+=head2 $cmd->hook_before_read_config_file($r)
+
+Only called when C<read_config> attribute is true.
+
+=head2 $cmd->hook_after_read_config_file($r)
+
+Only called when C<read_config> attribute is true.
+
 =head2 $cmd->hook_after_parse_argv($r)
 
 Called after C<run()> calls C<parse_argv()> and before it checks the result.
@@ -2003,20 +2020,15 @@ Can be used to set CLI program name.
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
