@@ -1,13 +1,15 @@
 package Perinci::CmdLine::Util::Config;
 
-our $DATE = '2015-03-30'; # DATE
-our $VERSION = '1.02'; # VERSION
+our $DATE = '2015-04-01'; # DATE
+our $VERSION = '1.03'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
+use PERLANCAR::File::HomeDir qw(get_my_home_dir);
+
 our %SPEC;
 
 $SPEC{get_default_config_dirs} = {
@@ -16,23 +18,14 @@ $SPEC{get_default_config_dirs} = {
 };
 sub get_default_config_dirs {
     my @dirs;
+    local $PERLANCAR::File::HomeDir::DIE_ON_FAILURE = 1;
+    my $home = get_my_home_dir();
     if ($^O eq 'MSWin32') {
-        require File::HomeDir;
-        push @dirs, File::HomeDir->my_home;
+        push @dirs, $home;
     } else {
-        my $home = $ENV{HOME};
-        unless ($home) {
-            # sometimes HOME is not defined, in that case we'll use getpwuid()
-            my @pw = getpwuid($>);
-            $home = $pw[7] if @pw;
-        }
-        if ($home) {
-            push @dirs, "$home/.config";
-            push @dirs, $home;
-        }
-        push @dirs, "/etc";
+        push @dirs, "$home/.config", $home, "/etc";
     }
-    [grep {defined} @dirs];
+    \@dirs;
 }
 
 $SPEC{read_config} = {
@@ -159,7 +152,7 @@ Perinci::CmdLine::Util::Config - Utility routines related to config files
 
 =head1 VERSION
 
-This document describes version 1.02 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-03-30.
+This document describes version 1.03 of Perinci::CmdLine::Util::Config (from Perl distribution Perinci-CmdLine-Lite), released on 2015-04-01.
 
 =head1 FUNCTIONS
 
@@ -241,20 +234,15 @@ Return value:  (any)
 
 =head1 HOMEPAGE
 
-Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.
+Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine-Lite>.=head1 SOURCE
 
-=head1 SOURCE
-
-Source repository is at L<https://github.com/sharyanto/perl-Perinci-CmdLine-Lite>.
-
-=head1 BUGS
+Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Lite>.=head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Lite>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
